"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


PostIntegrationsIntegrationIDRelinkRequestBodyLanguage = Literal[
    "en",
    "de",
    "fr",
    "it",
    "es",
]
r"""Language of the connection flow UI."""


PostIntegrationsIntegrationIDRelinkRequestBodyLinkType = Literal[
    "EMBEDDED",
    "MAGIC_LINK",
]
r"""The type of link you want to create. `EMBEDDED` is for the [embedded flow](../guides/connect/embedded-flow) using the Kombo Connect SDK (these links are valid for 1 hour) and `MAGIC_LINK` is for [magic links](../guides/connect/magic-links) which you send out manually to customers (there are valid for 1 year).

This defaults to `EMBEDDED`, which is our recommended method of implementing the connection flow for a seamless user experience.
"""


class PostIntegrationsIntegrationIDRelinkRequestBodyTypedDict(TypedDict):
    language: NotRequired[
        Nullable[PostIntegrationsIntegrationIDRelinkRequestBodyLanguage]
    ]
    r"""Language of the connection flow UI."""
    scope_config_id: NotRequired[Nullable[str]]
    r"""Specify a scope config which the integration will start using once the reconnection flow has been completed.

    This can be useful if you want to update the permissions of an integration, but only want the change to take effect once the user has updated their API credentials to prevent sync issues.
    """
    link_type: NotRequired[PostIntegrationsIntegrationIDRelinkRequestBodyLinkType]
    r"""The type of link you want to create. `EMBEDDED` is for the [embedded flow](../guides/connect/embedded-flow) using the Kombo Connect SDK (these links are valid for 1 hour) and `MAGIC_LINK` is for [magic links](../guides/connect/magic-links) which you send out manually to customers (there are valid for 1 year).

    This defaults to `EMBEDDED`, which is our recommended method of implementing the connection flow for a seamless user experience.
    """


class PostIntegrationsIntegrationIDRelinkRequestBody(BaseModel):
    language: OptionalNullable[
        PostIntegrationsIntegrationIDRelinkRequestBodyLanguage
    ] = "en"
    r"""Language of the connection flow UI."""

    scope_config_id: OptionalNullable[str] = UNSET
    r"""Specify a scope config which the integration will start using once the reconnection flow has been completed.

    This can be useful if you want to update the permissions of an integration, but only want the change to take effect once the user has updated their API credentials to prevent sync issues.
    """

    link_type: Optional[PostIntegrationsIntegrationIDRelinkRequestBodyLinkType] = (
        "EMBEDDED"
    )
    r"""The type of link you want to create. `EMBEDDED` is for the [embedded flow](../guides/connect/embedded-flow) using the Kombo Connect SDK (these links are valid for 1 hour) and `MAGIC_LINK` is for [magic links](../guides/connect/magic-links) which you send out manually to customers (there are valid for 1 year).

    This defaults to `EMBEDDED`, which is our recommended method of implementing the connection flow for a seamless user experience.
    """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["language", "scope_config_id", "link_type"]
        nullable_fields = ["language", "scope_config_id"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .assessmentorderreceivedwebhookpayload import (
    AssessmentOrderReceivedWebhookPayload,
    AssessmentOrderReceivedWebhookPayloadTypedDict,
)
from kombo.types import BaseModel
from kombo.utils import FieldMetadata, HeaderMetadata, RequestMetadata
import pydantic
from typing_extensions import Annotated, TypedDict


class WebhookAssessmentOrderReceivedWebhookPayloadRequestTypedDict(TypedDict):
    x_kombo_signature: str
    r"""HMAC signature for webhook verification. See the webhook documentation for details on how to verify this signature."""
    body: AssessmentOrderReceivedWebhookPayloadTypedDict


class WebhookAssessmentOrderReceivedWebhookPayloadRequest(BaseModel):
    x_kombo_signature: Annotated[
        str,
        pydantic.Field(alias="X-Kombo-Signature"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ]
    r"""HMAC signature for webhook verification. See the webhook documentation for details on how to verify this signature."""

    body: Annotated[
        AssessmentOrderReceivedWebhookPayload,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from kombo.types import BaseModel
from kombo.utils import validate_const
import pydantic
from pydantic.functional_validators import AfterValidator
from typing import Any, Dict, List, Literal, Optional, Union
from typing_extensions import Annotated, NotRequired, TypeAliasType, TypedDict


HeadersTypedDict = TypeAliasType("HeadersTypedDict", Union[str, List[str]])


Headers = TypeAliasType("Headers", Union[str, List[str]])


class PostPassthroughToolAPIPositiveResponseDataTypedDict(TypedDict):
    url: str
    r"""The full URL of the request that we automatically assemble for you based on the specified `api`, the specified `path`, and the integration's auth credentials. You can use this to debug path-related issues (e.g., the API returning 404 errors)."""
    status: int
    r"""The HTTP status code returned from the remote system."""
    headers: Dict[str, HeadersTypedDict]
    r"""The HTTP headers returned from the remote system."""
    data: NotRequired[Any]
    r"""The HTTP body returned from the remote system. This will either be an array or object (in the case that JSON was returned) or a string (in any other case)."""


class PostPassthroughToolAPIPositiveResponseData(BaseModel):
    url: str
    r"""The full URL of the request that we automatically assemble for you based on the specified `api`, the specified `path`, and the integration's auth credentials. You can use this to debug path-related issues (e.g., the API returning 404 errors)."""

    status: int
    r"""The HTTP status code returned from the remote system."""

    headers: Dict[str, Headers]
    r"""The HTTP headers returned from the remote system."""

    data: Optional[Any] = None
    r"""The HTTP body returned from the remote system. This will either be an array or object (in the case that JSON was returned) or a string (in any other case)."""


class PostPassthroughToolAPIPositiveResponseWarningTypedDict(TypedDict):
    message: str


class PostPassthroughToolAPIPositiveResponseWarning(BaseModel):
    message: str


class PostPassthroughToolAPIPositiveResponseTypedDict(TypedDict):
    data: PostPassthroughToolAPIPositiveResponseDataTypedDict
    warnings: List[PostPassthroughToolAPIPositiveResponseWarningTypedDict]
    r"""These are the interaction warnings that are shown in the dashboard. They are meant to provide debug information to you. We recommend logging them to the console."""
    status: Literal["success"]


class PostPassthroughToolAPIPositiveResponse(BaseModel):
    data: PostPassthroughToolAPIPositiveResponseData

    warnings: List[PostPassthroughToolAPIPositiveResponseWarning]
    r"""These are the interaction warnings that are shown in the dashboard. They are meant to provide debug information to you. We recommend logging them to the console."""

    STATUS: Annotated[
        Annotated[Literal["success"], AfterValidator(validate_const("success"))],
        pydantic.Field(alias="status"),
    ] = "success"



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .schema4 import Schema4, Schema4TypedDict
from kombo.types import BaseModel
from typing import Dict
from typing_extensions import TypedDict


class PostHrisEmployeesFormRequestBodyTypedDict(TypedDict):
    properties: Dict[str, Schema4TypedDict]


class PostHrisEmployeesFormRequestBody(BaseModel):
    properties: Dict[str, Schema4]
